@@ -2,52 +2,26 @@
 /**
  * This file is part of PHP Mess Detector.
  *
- * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
+ * Copyright (c) Manuel Pichler <mapi@phpmd.org>.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Manuel Pichler nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Licensed under BSD License
+ * For full copyright and license information, please see the LICENSE file.
+ * Redistributions of files must retain the above copyright notice.
  *
  * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright Manuel Pichler. All rights reserved.
+ * @license https://opensource.org/licenses/bsd-license.php BSD License
+ * @link http://phpmd.org/
  */
 
 namespace PHPMD;
 
+use PHPMD\Node\ClassNode;
+
 /**
  * This is the abstract base class for pmd rules.
  *
- * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
- *
  * @SuppressWarnings(PHPMD)
  */
 abstract class AbstractRule implements Rule
@@ -136,7 +110,6 @@ abstract class AbstractRule implements Rule
      * Sets the name for this rule instance.
      *
      * @param string $name The rule name.
-     *
      * @return void
      */
     public function setName($name)
@@ -158,7 +131,6 @@ abstract class AbstractRule implements Rule
      * Sets the version since when this rule is available.
      *
      * @param string $since The version number.
-     *
      * @return void
      */
     public function setSince($since)
@@ -180,7 +152,6 @@ abstract class AbstractRule implements Rule
      * Sets the violation message text for this rule.
      *
      * @param string $message The violation message
-     *
      * @return void
      */
     public function setMessage($message)
@@ -202,7 +173,6 @@ abstract class AbstractRule implements Rule
      * Sets an url will external information for this rule.
      *
      * @param string $externalInfoUrl The info url.
-     *
      * @return void
      */
     public function setExternalInfoUrl($externalInfoUrl)
@@ -224,7 +194,6 @@ abstract class AbstractRule implements Rule
      * Sets the description text for this rule instance.
      *
      * @param string $description The description text.
-     *
      * @return void
      */
     public function setDescription($description)
@@ -235,7 +204,7 @@ abstract class AbstractRule implements Rule
     /**
      * Returns a list of examples for this rule.
      *
-     * @return array(string)
+     * @return string[]
      */
     public function getExamples()
     {
@@ -246,7 +215,6 @@ abstract class AbstractRule implements Rule
      * Adds a code example for this rule.
      *
      * @param string $example The code example.
-     *
      * @return void
      */
     public function addExample($example)
@@ -268,7 +236,6 @@ abstract class AbstractRule implements Rule
      * Set the priority of this rule.
      *
      * @param integer $priority The rule priority
-     *
      * @return void
      */
     public function setPriority($priority)
@@ -290,7 +257,6 @@ abstract class AbstractRule implements Rule
      * Sets the name of the parent rule set instance.
      *
      * @param string $ruleSetName The rule-set name.
-     *
      * @return void
      */
     public function setRuleSetName($ruleSetName)
@@ -363,7 +329,6 @@ abstract class AbstractRule implements Rule
         throw new \OutOfBoundsException('Property "' . $name . '" does not exist.');
     }
 
-
     /**
      * Returns the raw string value of a configured property or throws an
      * exception when no property with <b>$name</b> exists.
@@ -378,7 +343,6 @@ abstract class AbstractRule implements Rule
             return $this->properties[$name];
         }
         throw new \OutOfBoundsException('Property "' . $name . '" does not exist.');
-
     }
 
     /**
@@ -408,6 +372,22 @@ abstract class AbstractRule implements Rule
         $this->report->addRuleViolation($ruleViolation);
     }
 
+    /**
+     * Apply the current rule on each method of a class node.
+     *
+     * @param ClassNode $node class node containing methods.
+     */
+    protected function applyOnClassMethods(ClassNode $node)
+    {
+        foreach ($node->getMethods() as $method) {
+            if ($method->hasSuppressWarningsAnnotationFor($this)) {
+                continue;
+            }
+
+            $this->apply($method);
+        }
+    }
+
     /**
      * This method should implement the violation analysis algorithm of concrete
      * rule implementations. All extending classes must implement this method.
