@@ -2,42 +2,17 @@
 /**
  * This file is part of PHP Mess Detector.
  *
- * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
+ * Copyright (c) Manuel Pichler <mapi@phpmd.org>.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Manuel Pichler nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Licensed under BSD License
+ * For full copyright and license information, please see the LICENSE file.
+ * Redistributions of files must retain the above copyright notice.
  *
  * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
- * @since      0.2.6
+ * @copyright Manuel Pichler. All rights reserved.
+ * @license https://opensource.org/licenses/bsd-license.php BSD License
+ * @link http://phpmd.org/
  */
 
 namespace PHPMD\Rule;
@@ -49,9 +24,6 @@ use PHPMD\Node\ASTNode;
 /**
  * Base class for rules that rely on local variables.
  *
- * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  * @since     0.2.6
  */
 abstract class AbstractLocalVariable extends AbstractRule
@@ -61,20 +33,23 @@ abstract class AbstractLocalVariable extends AbstractRule
      * can never be unused local variables.
      *
      * @var array(string=>boolean)
+     * @link http://php.net/manual/en/reserved.variables.php
      */
     private static $superGlobals = array(
-        '$argc'                => true,
-        '$argv'                => true,
-        '$_COOKIE'             => true,
-        '$_ENV'                => true,
-        '$_FILES'              => true,
-        '$_GET'                => true,
-        '$_POST'               => true,
-        '$_REQUEST'            => true,
-        '$_SERVER'             => true,
-        '$_SESSION'            => true,
-        '$GLOBALS'             => true,
-        '$HTTP_RAW_POST_DATA'  => true,
+        '$argc' => true,
+        '$argv' => true,
+        '$_COOKIE' => true,
+        '$_ENV' => true,
+        '$_FILES' => true,
+        '$_GET' => true,
+        '$_POST' => true,
+        '$_REQUEST' => true,
+        '$_SERVER' => true,
+        '$_SESSION' => true,
+        '$GLOBALS' => true,
+        '$HTTP_RAW_POST_DATA' => true,
+        '$php_errormsg' => true,
+        '$http_response_header' => true,
     );
 
     /**
