@@ -2,55 +2,28 @@
 /**
  * This file is part of PHP Mess Detector.
  *
- * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
+ * Copyright (c) Manuel Pichler <mapi@phpmd.org>.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Manuel Pichler nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Licensed under BSD License
+ * For full copyright and license information, please see the LICENSE file.
+ * Redistributions of files must retain the above copyright notice.
  *
  * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright Manuel Pichler. All rights reserved.
+ * @license https://opensource.org/licenses/bsd-license.php BSD License
+ * @link http://phpmd.org/
  */
 
 namespace PHPMD\Rule;
 
 use PHPMD\AbstractNode;
+use PHPMD\Node\ASTNode;
 use PHPMD\Node\MethodNode;
 
 /**
  * This rule collects all formal parameters of a given function or method that
  * are not used in a statement of the artifact's body.
- *
- * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 class UnusedFormalParameter extends AbstractLocalVariable implements FunctionAware, MethodAware
 {
@@ -194,16 +167,73 @@ class UnusedFormalParameter extends AbstractLocalVariable implements FunctionAwa
      * @return void
      */
     private function removeUsedParameters(AbstractNode $node)
+    {
+        $this->removeRegularVariables($node);
+        $this->removeCompoundVariables($node);
+        $this->removeVariablesUsedByFuncGetArgs($node);
+    }
+
+    /**
+     * Removes all the regular variables from a given node 
+     *
+     * @param \PHPMD\AbstractNode $node The node to remove the regular variables from.
+     * @return void
+     */
+    private function removeRegularVariables(AbstractNode $node)
     {
         $variables = $node->findChildrenOfType('Variable');
         foreach ($variables as $variable) {
+            /** @var $variable ASTNode */
             if ($this->isRegularVariable($variable)) {
                 unset($this->nodes[$variable->getImage()]);
             }
         }
+    }
+    
+    /**
+     * Removes all the compound variables from a given node 
+     *
+     * Such as
+     *
+     * <code>
+     * //   ------
+     * Foo::${BAR}();
+     * //   ------
+     *
+     * //    ------
+     * Foo::$${BAR}();
+     * //    ------
+     * </code>
+     *
+     * @param \PHPMD\AbstractNode $node The node to remove the compound variables from.
+     * @return void
+     */
+    private function removeCompoundVariables(AbstractNode $node)
+    {
+        $compoundVariables = $node->findChildrenOfType('CompoundVariable');
+        foreach ($compoundVariables as $compoundVariable) {
+            $variablePrefix = $compoundVariable->getImage();
 
-        /* If the method calls func_get_args() then all parameters are
-         * automatically referenced */
+            foreach ($compoundVariable->findChildrenOfType('Expression') as $child) {
+                $variableImage = $variablePrefix . $child->getImage();
+
+                if (isset($this->nodes[$variableImage])) {
+                    unset($this->nodes[$variableImage]);
+                }
+            }
+        }
+    }
+
+    /**
+     * Removes all the variables from a given node, if func_get_args() is called within
+     *
+     * If the given method calls func_get_args() then all parameters are automatically referenced.
+     *
+     * @param \PHPMD\AbstractNode $node The node to remove the referneced variables from.
+     * @return void
+     */
+    private function removeVariablesUsedByFuncGetArgs(AbstractNode $node)
+    {
         $functionCalls = $node->findChildrenOfType('FunctionPostfix');
         foreach ($functionCalls as $functionCall) {
             if ($this->isFunctionNameEqual($functionCall, 'func_get_args')) {
