@@ -2,41 +2,17 @@
 /**
  * This file is part of PHP Mess Detector.
  *
- * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
+ * Copyright (c) Manuel Pichler <mapi@phpmd.org>.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Manuel Pichler nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Licensed under BSD License
+ * For full copyright and license information, please see the LICENSE file.
+ * Redistributions of files must retain the above copyright notice.
  *
  * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright Manuel Pichler. All rights reserved.
+ * @license https://opensource.org/licenses/bsd-license.php BSD License
+ * @link http://phpmd.org/
  */
 
 namespace PHPMD\Rule;
@@ -48,10 +24,6 @@ use PHPMD\Node\ASTNode;
 /**
  * This rule collects all local variables within a given function or method
  * that are not used by any code in the analyzed source artifact.
- *
- * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 class UnusedLocalVariable extends AbstractLocalVariable implements FunctionAware, MethodAware
 {
@@ -73,6 +45,7 @@ class UnusedLocalVariable extends AbstractLocalVariable implements FunctionAware
     {
         $this->images = array();
 
+        /** @var $node AbstractCallableNode */
         $this->collectVariables($node);
         $this->removeParameters($node);
 
@@ -116,22 +89,52 @@ class UnusedLocalVariable extends AbstractLocalVariable implements FunctionAware
     private function collectVariables(AbstractCallableNode $node)
     {
         foreach ($node->findChildrenOfType('Variable') as $variable) {
+            /** @var $variable ASTNode */
             if ($this->isLocal($variable)) {
                 $this->collectVariable($variable);
             }
         }
+
+        foreach ($node->findChildrenOfType('CompoundVariable') as $variable) {
+            $this->collectCompoundVariableInString($variable);
+        }
+
         foreach ($node->findChildrenOfType('VariableDeclarator') as $variable) {
             $this->collectVariable($variable);
         }
         foreach ($node->findChildrenOfType('FunctionPostfix') as $func) {
             if ($this->isFunctionNameEndingWith($func, 'compact')) {
                 foreach ($func->findChildrenOfType('Literal') as $literal) {
+                    /** @var $literal ASTNode */
                     $this->collectLiteral($literal);
                 }
             }
         }
     }
 
+    /**
+     * Stores the given compound variable node in an internal list of found variables.
+     *
+     * @param \PHPMD\Node\ASTNode $node
+     * @return void
+     */
+    private function collectCompoundVariableInString(ASTNode $node)
+    {
+        $parentNode = $node->getParent()->getNode();
+        $candidateParentNodes = $node->getParentsOfType('PDepend\Source\AST\ASTString');
+
+        if (in_array($parentNode, $candidateParentNodes)) {
+            $variablePrefix = $node->getImage();
+
+            foreach ($node->findChildrenOfType('Expression') as $child) {
+                $variableName = $child->getImage();
+                $variableImage = $variablePrefix . $variableName;
+
+                $this->storeImage($variableImage, $node);
+            }
+        }
+    }
+
     /**
      * Stores the given variable node in an internal list of found variables.
      *
@@ -140,10 +143,23 @@ class UnusedLocalVariable extends AbstractLocalVariable implements FunctionAware
      */
     private function collectVariable(ASTNode $node)
     {
-        if (!isset($this->images[$node->getImage()])) {
-            $this->images[$node->getImage()] = array();
+        $imageName = $node->getImage();
+        $this->storeImage($imageName, $node);
+    }
+
+    /**
+     * Safely add node to $this->images.
+     *
+     * @param string $imageName         the name to store the node as
+     * @param \PHPMD\Node\ASTNode $node the node being stored
+     * @return void
+     */
+    private function storeImage($imageName, ASTNode $node)
+    {
+        if (!isset($this->images[$imageName])) {
+            $this->images[$imageName] = array();
         }
-        $this->images[$node->getImage()][] = $node;
+        $this->images[$imageName][] = $node;
     }
 
     /**
@@ -164,10 +180,10 @@ class UnusedLocalVariable extends AbstractLocalVariable implements FunctionAware
     /**
      * Template method that performs the real node image check.
      *
-     * @param \PHPMD\AbstractNode $node
+     * @param ASTNode $node
      * @return void
      */
-    protected function doCheckNodeImage(AbstractNode $node)
+    protected function doCheckNodeImage(ASTNode $node)
     {
         if ($this->isNameAllowedInContext($node)) {
             return;
@@ -175,6 +191,10 @@ class UnusedLocalVariable extends AbstractLocalVariable implements FunctionAware
         if ($this->isUnusedForeachVariableAllowed($node)) {
             return;
         }
+        $exceptions = $this->getExceptionsList();
+        if (in_array(substr($node->getImage(), 1), $exceptions)) {
+            return;
+        }
         $this->addViolation($node, array($node->getImage()));
     }
 
@@ -220,7 +240,23 @@ class UnusedLocalVariable extends AbstractLocalVariable implements FunctionAware
     private function isChildOf(AbstractNode $node, $type)
     {
         $parent = $node->getParent();
-        
+
         return $parent->isInstanceOf($type);
     }
+
+    /**
+     * Gets array of exceptions from property
+     *
+     * @return array
+     */
+    private function getExceptionsList()
+    {
+        try {
+            $exceptions = $this->getStringProperty('exceptions');
+        } catch (\OutOfBoundsException $e) {
+            $exceptions = '';
+        }
+
+        return explode(',', $exceptions);
+    }
 }
