@@ -2,45 +2,24 @@
 /**
  * This file is part of PHP Mess Detector.
  *
- * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
+ * Copyright (c) Manuel Pichler <mapi@phpmd.org>.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Manuel Pichler nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Licensed under BSD License
+ * For full copyright and license information, please see the LICENSE file.
+ * Redistributions of files must retain the above copyright notice.
  *
  * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright Manuel Pichler. All rights reserved.
+ * @license https://opensource.org/licenses/bsd-license.php BSD License
+ * @link http://phpmd.org/
  */
 
 namespace PHPMD;
 
+use PDepend\Source\AST\ASTClass;
+use PDepend\Source\AST\ASTFunction;
+use PDepend\Source\AST\ASTMethod;
 use PDepend\Source\Language\PHP\PHPBuilder;
 use PDepend\Source\Language\PHP\PHPParserGeneric;
 use PDepend\Source\Language\PHP\PHPTokenizerInternal;
@@ -50,14 +29,12 @@ use PHPMD\Node\FunctionNode;
 use PHPMD\Node\InterfaceNode;
 use PHPMD\Node\MethodNode;
 use PHPMD\Node\TraitNode;
+use PHPMD\Rule\Design\TooManyFields;
 use PHPMD\Stubs\RuleStub;
+use PHPUnit_Framework_MockObject_MockBuilder;
 
 /**
  * Abstract base class for PHPMD test cases.
- *
- * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 abstract class AbstractTest extends \PHPUnit_Framework_TestCase
 {
@@ -193,7 +170,6 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      * Returns the absolute path for a test resource for the current test.
      *
      * @param string $localPath The local/relative file location
-     *
      * @return string
      * @since 1.1.0
      */
@@ -232,6 +208,7 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      * Returns the trace frame of the calling test case.
      *
      * @return array
+     * @throws \ErrorException
      */
     private static function getCallingTestCase()
     {
@@ -248,6 +225,7 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      *
      * @param \Iterator $nodes
      * @return PHP_Depend_Code_AbstractItem
+     * @throws \ErrorException
      */
     private function getNodeForCallingTestCase(\Iterator $nodes)
     {
@@ -298,12 +276,9 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      */
     protected function getClassMock($metric = null, $value = null)
     {
-        $class = $this->getMock(
-            'PHPMD\\Node\\ClassNode',
-            array(),
-            array(null),
-            '',
-            false
+        $class = $this->getMockFromBuilder(
+            $this->getMockBuilder('PHPMD\\Node\\ClassNode')
+                ->setConstructorArgs(array(new ASTClass('FooBar')))
         );
 
         if ($metric !== null) {
@@ -325,7 +300,10 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
     protected function getMethodMock($metric = null, $value = null)
     {
         return $this->initFunctionOrMethod(
-            $this->getMock('PHPMD\\Node\\MethodNode', array(), array(null), '', false),
+            $this->getMockFromBuilder(
+                $this->getMockBuilder('PHPMD\\Node\\MethodNode')
+                    ->setConstructorArgs(array(new ASTMethod('fooBar')))
+            ),
             $metric,
             $value
         );
@@ -336,13 +314,15 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      *
      * @param string $metric The metric acronym used by PHP_Depend.
      * @param mixed  $value  The expected metric return value.
-     *
      * @return \PHPMD\Node\FunctionNode
      */
     protected function createFunctionMock($metric = null, $value = null)
     {
         return $this->initFunctionOrMethod(
-            $this->getMock('PHPMD\\Node\\FunctionNode', array(), array(null), '', false),
+            $this->getMockFromBuilder(
+                $this->getMockBuilder('PHPMD\\Node\\FunctionNode')
+                    ->setConstructorArgs(array(new ASTFunction('fooBar')))
+            ),
             $metric,
             $value
         );
@@ -374,7 +354,6 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      * Creates a mocked report instance.
      *
      * @param integer $expectedInvokes Number of expected invokes.
-     *
      * @return \PHPMD\Report
      */
     protected function getReportMock($expectedInvokes = -1)
@@ -389,13 +368,22 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
             $expects = $this->exactly($expectedInvokes);
         }
 
-        $report = $this->getMock('PHPMD\\Report');
+        $report = $this->getMockFromBuilder($this->getMockBuilder('PHPMD\\Report'));
         $report->expects($expects)
             ->method('addRuleViolation');
 
         return $report;
     }
 
+    protected function getMockFromBuilder(PHPUnit_Framework_MockObject_MockBuilder $builder)
+    {
+        if (version_compare(phpversion(), '7.4.0-dev', '<')) {
+            return $builder->getMock();
+        }
+
+        return @$builder->getMock();
+    }
+
     /**
      * Creates a mocked {@link \PHPMD\AbstractRule} instance.
      *
@@ -403,7 +391,11 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      */
     protected function getRuleMock()
     {
-        return $this->getMockForAbstractClass('PHPMD\\AbstractRule');
+        if (version_compare(phpversion(), '7.4.0-dev', '<')) {
+            return $this->getMockForAbstractClass('PHPMD\\AbstractRule');
+        }
+
+        return @$this->getMockForAbstractClass('PHPMD\\AbstractRule');
     }
 
     /**
@@ -415,7 +407,7 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      */
     protected function getRuleSetMock($expectedClass = null, $count = '*')
     {
-        $ruleSet = $this->getMock('PHPMD\RuleSet');
+        $ruleSet = $this->getMockFromBuilder($this->getMockBuilder('PHPMD\RuleSet'));
         if ($expectedClass === null) {
             $ruleSet->expects($this->never())->method('apply');
         } else {
@@ -429,32 +421,35 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
     }
 
     /**
-     * Creates a mocked rul violation instance.
+     * Creates a mocked rule violation instance.
      *
-     * @param string  $fileName
-     * @param integer $beginLine
-     * @param integer $endLine
-     * @param object  $rule
-     * @return \PHPMD\RuleViolation
+     * @param string $fileName The filename to use.
+     * @param integer $beginLine The begin of violation line number to use.
+     * @param integer $endLine The end of violation line number to use.
+     * @param null|object $rule The rule object to use.
+     * @param null|string $description The violation description to use.
+     * @return \PHPUnit_Framework_MockObject_MockObject
      */
     protected function getRuleViolationMock(
         $fileName = '/foo/bar.php',
         $beginLine = 23,
         $endLine = 42,
-        $rule = null
+        $rule = null,
+        $description = null
     ) {
-        $ruleViolation = $this->getMock(
-            'PHPMD\\RuleViolation',
-            array(),
-            array(null, null, null),
-            '',
-            false
+        $ruleViolation = $this->getMockFromBuilder(
+            $this->getMockBuilder('PHPMD\\RuleViolation')
+                ->setConstructorArgs(array(new TooManyFields(), new FunctionNode(new ASTFunction('fooBar')), 'Hello'))
         );
 
         if ($rule === null) {
             $rule = new RuleStub();
         }
 
+        if ($description === null) {
+            $description = 'Test description';
+        }
+
         $ruleViolation->expects($this->any())
             ->method('getRule')
             ->will($this->returnValue($rule));
@@ -472,17 +467,43 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
             ->will($this->returnValue('TestStubPackage'));
         $ruleViolation->expects($this->any())
             ->method('getDescription')
-            ->will($this->returnValue('Test description'));
+            ->will($this->returnValue($description));
 
         return $ruleViolation;
     }
 
+    /**
+     * Creates a mocked rul violation instance.
+     *
+     * @param string  $file
+     * @param string  $message
+     * @return \PHPMD\ProcessingError
+     */
+    protected function getErrorMock(
+        $file = '/foo/baz.php',
+        $message = 'Error in file "/foo/baz.php"') {
+
+        $processingError = $this->getMockFromBuilder(
+            $this->getMockBuilder('PHPMD\\ProcessingError')
+                ->setConstructorArgs(array(null))
+                ->setMethods(array('getFile', 'getMessage'))
+        );
+
+        $processingError->expects($this->any())
+            ->method('getFile')
+            ->will($this->returnValue($file));
+        $processingError->expects($this->any())
+            ->method('getMessage')
+            ->will($this->returnValue($message));
+
+        return $processingError;
+    }
+
     /**
      * Asserts the actual xml output matches against the expected file.
      *
      * @param string $actualOutput     Generated xml output.
      * @param string $expectedFileName File with expected xml result.
-     *
      * @return void
      */
     public static function assertXmlEquals($actualOutput, $expectedFileName)
@@ -510,6 +531,39 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
         self::assertXmlStringEqualsXmlString($expected, $actual->saveXML());
     }
 
+    /**
+     * Asserts the actual JSON output matches against the expected file.
+     *
+     * @param string $actualOutput     Generated JSON output.
+     * @param string $expectedFileName File with expected JSON result.
+     *
+     * @return void
+     */
+    public static function assertJsonEquals($actualOutput, $expectedFileName)
+    {
+        $actual = json_decode($actualOutput, true);
+        // Remove dynamic timestamp and duration attribute
+        if (isset($actual['timestamp'])) {
+            $actual['timestamp'] = '';
+        }
+        if (isset($actual['duration'])) {
+            $actual['duration'] = '';
+        }
+        if (isset($actual['version'])) {
+            $actual['version'] = '@package_version@';
+        }
+
+        $expected = str_replace(
+            '#{rootDirectory}',
+            self::$filesDirectory,
+            file_get_contents(self::createFileUri($expectedFileName))
+        );
+
+        $expected = str_replace('_DS_', DIRECTORY_SEPARATOR, $expected);
+
+        self::assertJsonStringEqualsJsonString($expected, json_encode($actual));
+    }
+
     /**
      * This method initializes the test environment, it configures the files
      * directory and sets the include_path for svn versions.
@@ -541,7 +595,6 @@ abstract class AbstractTest extends \PHPUnit_Framework_TestCase
      * Changes the working directory for a single test.
      *
      * @param string $localPath The temporary working directory.
-     *
      * @return void
      */
     protected static function changeWorkingDirectory($localPath = '')
