@@ -2,41 +2,17 @@
 /**
  * This file is part of PHP Mess Detector.
  *
- * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
+ * Copyright (c) Manuel Pichler <mapi@phpmd.org>.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Manuel Pichler nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Licensed under BSD License
+ * For full copyright and license information, please see the LICENSE file.
+ * Redistributions of files must retain the above copyright notice.
  *
  * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright Manuel Pichler. All rights reserved.
+ * @license https://opensource.org/licenses/bsd-license.php BSD License
+ * @link http://phpmd.org/
  */
 
 namespace PHPMD\Rule;
@@ -46,15 +22,8 @@ use PHPMD\AbstractTest;
 /**
  * Test case for the unused local variable rule.
  *
- * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
- *
  * @covers \PHPMD\Rule\UnusedLocalVariable
  * @covers \PHPMD\Rule\AbstractLocalVariable
- * @group phpmd
- * @group phpmd::rule
- * @group unittest
  */
 class UnusedLocalVariableTest extends AbstractTest
 {
@@ -130,6 +99,28 @@ class UnusedLocalVariableTest extends AbstractTest
         $rule->apply($this->getMethod());
     }
 
+    /**
+     * testRuleDoesApplyToCompoundVariableInString
+     *
+     * <code>
+     * class Foo
+     *     function bar() {
+     *         $baz = 23;
+     *         return "${baz}_wibble";
+     *     }
+     * }
+     * </code>
+     *
+     * @return void
+     */
+    public function testRuleDoesApplyToCompoundVariableInString()
+    {
+        $rule = new UnusedLocalVariable();
+        $rule->addProperty('allow-unused-foreach-variables', 'false');
+        $rule->setReport($this->getReportMock(0));
+        $rule->apply($this->getMethod());
+    }
+
     /**
      * testRuleDoesNotApplyToLocalVariableUsedInCompoundVariable
      *
@@ -472,7 +463,6 @@ class UnusedLocalVariableTest extends AbstractTest
         $rule->apply($this->getMethod());
     }
 
-
     /**
      * testRuleAppliesToUnusedForeachValueWhenNotIgnored
      *
@@ -486,7 +476,6 @@ class UnusedLocalVariableTest extends AbstractTest
         $rule->apply($this->getMethod());
     }
 
-
     /**
      * testRuleDoesNotApplyToUnusedForeachKeyWhenIgnored
      *
@@ -500,6 +489,47 @@ class UnusedLocalVariableTest extends AbstractTest
         $rule->apply($this->getMethod());
     }
 
+    /**
+     * testRuleDoesNotApplyToUnusedForeachKeyWhenWhitelisted
+     *
+     * @return void
+     */
+    public function testRuleDoesNotApplyToUnusedForeachKeyWhenWhitelisted()
+    {
+        $rule = new UnusedLocalVariable();
+        $rule->addProperty('allow-unused-foreach-variables', 'false');
+        $rule->addProperty('exceptions', '_');
+        $rule->setReport($this->getReportMock(0));
+        $rule->apply($this->getMethod());
+    }
+
+    /**
+     * testRuleDoesNotAppliesToWhitelistedUnusedLocaleVariable
+     *
+     * @return void
+     */
+    public function testRuleDoesNotAppliesToWhitelistedUnusedLocaleVariable()
+    {
+        $rule = new UnusedLocalVariable();
+        $rule->addProperty('allow-unused-foreach-variables', 'false');
+        $rule->addProperty('exceptions', '_');
+        $rule->setReport($this->getReportMock(0));
+        $rule->apply($this->getMethod());
+    }
+
+    /**
+     * testRuleStillAppliesWhenSomeUnusedLocaleAreWhitelisted
+     *
+     * @return void
+     */
+    public function testRuleStillAppliesWhenSomeUnusedLocaleAreWhitelisted()
+    {
+        $rule = new UnusedLocalVariable();
+        $rule->addProperty('allow-unused-foreach-variables', 'false');
+        $rule->addProperty('exceptions', '_');
+        $rule->setReport($this->getReportMock(1));
+        $rule->apply($this->getMethod());
+    }
 
     /**
      * testRuleDoesNotApplyToUnusedForeachValueWhenIgnored
@@ -631,4 +661,17 @@ class UnusedLocalVariableTest extends AbstractTest
         $rule->setReport($this->getReportMock(0));
         $rule->apply($this->getMethod());
     }
+
+    /**
+     * testRuleNotAppliesToPredefinedVariables.php
+     *
+     * @return void
+     */
+    public function testRuleNotAppliesToPredefinedVariables()
+    {
+        $rule = new UnusedLocalVariable();
+        $rule->addProperty('allow-unused-foreach-variables', 'false');
+        $rule->setReport($this->getReportMock(1));
+        $rule->apply($this->getMethod());
+    }
 }
