@@ -2,58 +2,37 @@
 /**
  * This file is part of PHP Mess Detector.
  *
- * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
+ * Copyright (c) Manuel Pichler <mapi@phpmd.org>.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Manuel Pichler nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Licensed under BSD License
+ * For full copyright and license information, please see the LICENSE file.
+ * Redistributions of files must retain the above copyright notice.
  *
  * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright Manuel Pichler. All rights reserved.
+ * @license https://opensource.org/licenses/bsd-license.php BSD License
+ * @link http://phpmd.org/
  */
 
 namespace PHPMD;
 
+use org\bovigo\vfs\vfsStream;
+
 /**
  * Test case for the rule set factory class.
  *
- * @author Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
- *
  * @covers \PHPMD\RuleSetFactory
- * @group phpmd
- * @group unittest
  */
 class RuleSetFactoryTest extends AbstractTest
 {
+    /**
+     * Used to test files/directories access for ignore code rule
+     *
+     * @var string
+     */
+    const DIR_UNDER_TESTS = 'designăôü0汉字';
+
     /**
      * testCreateRuleSetFileNameFindsXmlFileInBundledRuleSets
      *
@@ -204,7 +183,7 @@ class RuleSetFactoryTest extends AbstractTest
     public function testCreateRuleSetsForLocalFileNameReturnsArray()
     {
         self::changeWorkingDirectory();
-        
+
         $ruleSets = $this->createRuleSetsFromFiles('rulesets/set1.xml');
         $this->assertInternalType('array', $ruleSets);
     }
@@ -287,11 +266,11 @@ class RuleSetFactoryTest extends AbstractTest
 
         $actual   = array();
         $expected = array('RuleTwoInFirstRuleSet', 'RuleOneInSecondRuleSet');
-        
+
         foreach ($ruleSets[0]->getRules() as $rule) {
             $actual[] = $rule->getName();
         }
-        
+
         $this->assertEquals($expected, $actual);
     }
 
@@ -306,16 +285,16 @@ class RuleSetFactoryTest extends AbstractTest
 
         $factory = new RuleSetFactory();
         $ruleSet = $factory->createSingleRuleSet('set1');
-        
+
         $this->assertInstanceOf('PHPMD\\RuleSet', $ruleSet);
     }
 
     /**
-     * Tests that the rule-set factory applies a set priority filter correct.
+     * Tests that the rule-set factory applies a set minimum priority filter correct.
      *
      * @return void
      */
-    public function testCreateRuleSetWithSpecifiedPriorityOnlyContainsMatchingRules()
+    public function testCreateRuleSetWithSpecifiedMinimumPriorityOnlyContainsMatchingRules()
     {
         self::changeWorkingDirectory();
 
@@ -326,6 +305,39 @@ class RuleSetFactoryTest extends AbstractTest
         $this->assertSame(1, iterator_count($ruleSet->getRules()));
     }
 
+    /**
+     * Tests that the rule-set factory applies a set maximum priority filter correct.
+     *
+     * @return void
+     */
+    public function testCreateRuleSetWithSpecifiedMaximumPriorityOnlyContainsMatchingRules()
+    {
+        self::changeWorkingDirectory();
+
+        $factory = new RuleSetFactory();
+        $factory->setMaximumPriority(2);
+
+        $ruleSet = $factory->createSingleRuleSet('set1');
+        $this->assertSame(1, iterator_count($ruleSet->getRules()));
+    }
+
+    /**
+     * Tests that the rule-set factory applies a set maximum priority filter correct.
+     *
+     * @return void
+     */
+    public function testCreateRuleSetWithSpecifiedPrioritiesOnlyContainsMatchingRules()
+    {
+        self::changeWorkingDirectory();
+
+        $factory = new RuleSetFactory();
+        $factory->setMinimumPriority(2);
+        $factory->setMaximumPriority(2);
+
+        $ruleSet = $factory->createSingleRuleSet('set1');
+        $this->assertCount(0, $ruleSet->getRules());
+    }
+
     /**
      * testCreateRuleWithExcludePattern
      *
@@ -358,7 +370,7 @@ class RuleSetFactoryTest extends AbstractTest
         $ruleSets = $factory->createRuleSets('refset3');
 
         $rule = $ruleSets[0]->getRules()->current();
-        $this->assertSame(-42, $rule->getPriority());
+        $this->assertSame(4, $rule->getPriority());
     }
 
     /**
@@ -630,42 +642,71 @@ class RuleSetFactoryTest extends AbstractTest
 
         $this->assertAttributeEquals(true, 'strict', $ruleSets[0]);
     }
-    
+
     /**
      * Tests that adding an include-path via ruleset works.
      * Also implicitly tests (by parsing the ruleset) that
      * reference-by-includepath and explicit-classfile-declaration works.
      *
      * @return void
+     * @throws \Exception
      */
     public function testAddPHPIncludePath()
     {
         $includePathBefore = get_include_path();
-        
+
         $rulesetFilepath = 'rulesets/ruleset-refs.xml';
         $fileName = self::createFileUri($rulesetFilepath);
-        
+
         try {
             $factory = new RuleSetFactory();
             $factory->createRuleSets($fileName);
-            
+
             $expectedIncludePath  = "/foo/bar/baz";
             $actualIncludePaths   = explode(PATH_SEPARATOR, get_include_path());
             $isIncludePathPresent = in_array($expectedIncludePath, $actualIncludePaths);
-        
         } catch (\Exception $exception) {
             set_include_path($includePathBefore);
             throw $exception;
         }
-        
+
         set_include_path($includePathBefore);
-        
+
         $this->assertTrue(
             $isIncludePathPresent,
             "The include-path from '{$rulesetFilepath}' was not set!"
         );
     }
 
+    /**
+     * Checks if PHPMD doesn't treat directories named as code rule as files
+     *
+     * @return void
+     * @link https://github.com/phpmd/phpmd/issues/47
+     */
+    public function testIfGettingRuleFilePathExcludeUnreadablePaths()
+    {
+        self::changeWorkingDirectory(__DIR__);
+        $factory = new RuleSetFactory();
+        $runtimeExceptionCount = 0;
+        $ruleSetNotFoundExceptionCount = 0;
+
+        foreach ($this->getPathsForFileAccessTest() as $path) {
+            try {
+                $this->assertEquals(
+                    array('some/excluded/files'),
+                    $factory->getIgnorePattern($path . self::DIR_UNDER_TESTS)
+                );
+            } catch (RuleSetNotFoundException $e) {
+                $ruleSetNotFoundExceptionCount++;
+            } catch (\RuntimeException $e) {
+                $runtimeExceptionCount++;
+            }
+        }
+        $this->assertEquals(0, $runtimeExceptionCount);
+        $this->assertEquals(5, $ruleSetNotFoundExceptionCount);
+    }
+
     /**
      * Invokes the <b>createRuleSets()</b> of the {@link RuleSetFactory}
      * class.
@@ -697,4 +738,47 @@ class RuleSetFactoryTest extends AbstractTest
         $factory = new RuleSetFactory();
         return $factory->createRuleSets(join(',', $args));
     }
+
+    /**
+     * Sets up files and directories for XML rule file access test
+     *
+     * @return array Paths to test against
+     */
+    public function getPathsForFileAccessTest()
+    {
+        $fileContent = file_get_contents(__DIR__ . '/../../resources/files/rulesets/exclude-pattern.xml');
+        $structure = array(
+            'dir1' => array(
+                self::DIR_UNDER_TESTS => array(), // directory - skipped
+                'foo' => array(), // directory, criteria do not apply
+            ),
+            'dir2' => array(
+                self::DIR_UNDER_TESTS => array(), // directory, wrong permissions
+            ),
+            'dir3' => array(
+                self::DIR_UNDER_TESTS => array(), // directory, wrong owner and group
+            ),
+            'dirÅ' => array( // check UTF-8 characters handling
+                'foo' => array(
+                    self::DIR_UNDER_TESTS => $fileContent, // wrong permissions
+                ),
+                'bar' => array(
+                    self::DIR_UNDER_TESTS => $fileContent, // OK
+                ),
+            ),
+        );
+        $root = vfsStream::setup('root', null, $structure);
+        $root->getChild('dir2/' . self::DIR_UNDER_TESTS)->chmod(000);
+        $root->getChild('dir3/' . self::DIR_UNDER_TESTS)->chown(vfsStream::OWNER_ROOT)->chgrp(vfsStream::GROUP_ROOT);
+        $root->getChild('dirÅ/foo/' . self::DIR_UNDER_TESTS)->chmod(000);
+
+        return array(
+            $root->url(),
+            $root->url() . '/dir1/',
+            $root->url() . '/dir2/',
+            $root->url() . '/dir3/',
+            $root->url() . '/dirÅ/foo/',
+            $root->url() . '/dirÅ/bar/',
+        );
+    }
 }
